<template>
    <v-dialog v-model="dialog" persistent max-width="700">
        <v-card>
            <v-card-title class="text-h6">
                {{ pageTitle }}
            </v-card-title>
            <v-card-text>
                <v-form>
                    <v-text-field autofocus label="Category name" maxlength="25" counter
                                  v-model="form.name"></v-text-field>
                </v-form>
                <v-divider/>
            </v-card-text>
            <v-card-actions>
                <v-btn color="error darken-1" text @click="$emit('close')">
                    <v-icon left dark>mdi-close</v-icon>
                    Close
                </v-btn>
                <v-spacer/>
                <v-btn color="green darken-1" text dark @click="saveCategory">
                    <v-icon left dark>mdi-content-save-outline</v-icon>
                    {{ buttonText }}
                </v-btn>
            </v-card-actions>
        </v-card>
    </v-dialog>
</template>

<script>
export default {
    name: "CreateCategoryDialog",
    props: {
        display: {
            type: Boolean,
            required: true
        },
        category: {
            type: Object,
            required: false,
            default: () => ({})
        }
    },
    data() {
        return {
            dialog: false,
            tab: null,
            form: {
                name: ''
            }
        }
    },
    computed: {
        edit() {
            return this.category.id
        },
        buttonText() {
            return this.edit ? 'Update' : 'Save'
        },
        pageTitle() {
            return this.edit ? `Update an article` : "Add a new article"
        }
    },
    watch: {
        display(value) {
            this.dialog = value
        },
        category(value) {
            if (value.id) {
                this.form.name = this.category.name
            }
        }
    },
    methods: {
        dataTemplate() {
            return {}
        },
        saveCategory() {
            if (this.edit) {
                axios.post(this.$route('post.category.update', {category: this.edit}), this.form)
                    .then(res => res.data)
                    .then(data => {
                        this.$emit('category-updated', data)
                        this.closeDialog()
                    })
            } else {
                axios.post(this.$route('post.category.store'), this.form)
                    .then(res => res.data)
                    .then(data => {
                        this.$emit('category-created', data)
                        this.closeDialog()
                    })
            }
        },
        closeDialog() {
            this.$emit('close')
        },
    },
    mounted() {
    }
}
</script>

<style scoped>

</style>
